@@ -1,8 +1,8 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-03-24 10:42:34
-:LastEditTime: 2021-10-14 19:00:36
-:LastEditors: HuangJingCan
+:LastEditTime: 2022-04-27 16:30:28
+:LastEditors: ChenXiaolei
 :Description: StudioBaseHandler
 """
 
@@ -134,12 +134,7 @@ class StudioBaseHandler(BaseCookieHandler):
         :return: redis_cli
         :last_editors: HuangJingCan
         """
-        host = config.get_value("redis")["host"]
-        port = config.get_value("redis")["port"]
-        if not db:
-            db = config.get_value("redis")["db"]
-        password = config.get_value("redis")["password"]
-        redis_cli = RedisHelper.redis_init(host, port, db, password)
+        redis_cli = RedisHelper.redis_init(config_dict=config.get_value("redis"))
         return redis_cli
 
     def set_default_headers(self):
