@@ -1,7 +1,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-03-24 19:48:05
-:LastEditTime: 2021-02-06 15:50:20
+:LastEditTime: 2021-10-14 15:04:44
 :LastEditors: HuangJingCan
 :Description: 
 """
@@ -167,18 +167,7 @@ class LoginPlatformHandler(StudioBaseHandler):
         user_login.UserToken = UUIDHelper.get_uuid()
         user_login.ExpireTime = TimeHelper.add_hours_by_format_time(hour=config.get_value("login_expire"))
 
-        if config.get_value("login_type") == "redis":
-            self.redis_init().hset(config.get_value("redis_provider_name_user_login"), user_login.UserID, self.json_dumps(user_login))
-        else:
-            user_login_base = UserLoginModel(config.get_value("base_manage_context_key"))
-            user_login_base.add_update_entity(user_login, "UserIDMD5=%s,ExpireTime=%s,UserToken=%s", [user_login.UserIDMD5, user_login.ExpireTime, user_login.UserToken])
-
-        # self.set_secure_cookie(name="UserID", value=user_login.UserID,domain=".gao7.com")
-        # self.set_secure_cookie(name="UserIDMD5", value=user_login.UserIDMD5, domain=".gao7.com")
-        # self.set_secure_cookie(name="UserToken", value=user_login.UserToken, domain=".gao7.com")
-        self.set_secure_cookie("UserID", user_login.UserID)
-        self.set_secure_cookie("UserIDMD5", user_login.UserIDMD5)
-        self.set_secure_cookie("UserToken", user_login.UserToken)
+        self.login_cookie(user_login)
 
         return user_login
 
